<?php

namespace Litecms\PackageSetting\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\PackageSetting\Models\PackageSetting;

class PackageSettingPolicy
{

    /**
     * Determine if the given user can view the package_setting.
     *
     * @param UserPolicy $user
     * @param PackageSetting $package_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, PackageSetting $package_setting)
    {
        if ($user->canDo('package_setting.package_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $package_setting->user_id == user_id() && $package_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a package_setting.
     *
     * @param UserPolicy $user
     * @param PackageSetting $package_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('package_setting.package_setting.create');
    }

    /**
     * Determine if the given user can update the given package_setting.
     *
     * @param UserPolicy $user
     * @param PackageSetting $package_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, PackageSetting $package_setting)
    {
        if ($user->canDo('package_setting.package_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $package_setting->user_id == user_id() && $package_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given package_setting.
     *
     * @param UserPolicy $user
     * @param PackageSetting $package_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, PackageSetting $package_setting)
    {
        return $package_setting->user_id == user_id() && $package_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given package_setting.
     *
     * @param UserPolicy $user
     * @param PackageSetting $package_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, PackageSetting $package_setting)
    {
        if ($user->canDo('package_setting.package_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given package_setting.
     *
     * @param UserPolicy $user
     * @param PackageSetting $package_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, PackageSetting $package_setting)
    {
        if ($user->canDo('package_setting.package_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
